using System;
using System.Xml;
using System.Collections.Generic;

/// <summary>
/// Helps out with finding a Microformat in XML
/// </summary>
public class MicroFormatFinder
{

    // recursive method that filters through a node and its children,
    // returning any microformats that it contains
    public static List<MicroFormat> FindMicroFormats(XmlNode node)
    {
        List<MicroFormat> mfList = new List<MicroFormat>();

        // check the current node to see if it contains a microformat
        if (node.Attributes != null && node.Attributes["class"] != null)
        {
            string[] attrVals = node.Attributes["class"].Value.Split(' ');
            foreach (string val in attrVals)
            {
                if (val == "vcard")
                {
                    mfList.Add(new HCardMicroFormat(node));
                }
            }
        }

        // add all of the hcards found in this items children
        if (node.HasChildNodes)
        {
            foreach (XmlNode child in node.ChildNodes)
            {
                mfList.AddRange(FindMicroFormats(child));
            }
        }

        return mfList;
    }
}
